---
title: <span class="badge object-type-scalar"></span> Gigabytes
---
# <span class="badge object-type-scalar"></span> Gigabytes

Data: gigabytes

## Definition

```python
# Data: gigabytes
Gigabytes: typing.Literal["decgbytes"] = "decgbytes"
```
